@@ -3,6 +3,7 @@ RunModel_CemaNeigeGR5J <- function(InputsModel,RunOptions,Param){
   
   IsHyst <- inherits(RunOptions, "hysteresis")
   NParam <- ifelse(test = IsHyst, yes = 9L, no = 7L)
+  NParamCN <- NParam - 5L
   NStates <- 4L
   FortranOutputs <- .FortranOutputs(GR = "GR5J", isCN = TRUE)
 
@@ -61,23 +62,23 @@ RunModel_CemaNeigeGR5J <- function(InputsModel,RunOptions,Param){
         } else {
           StateStartCemaNeige <- RunOptions$IniStates[(7 + 20 + 40) + c(iLayer, iLayer+NLayers, iLayer+2*NLayers, iLayer+3*NLayers)]
         }
-        RESULTS <- .Fortran("frun_CemaNeige",PACKAGE="airGR",
+        RESULTS <- .Fortran("frun_cemaneige",PACKAGE="airGR",
                         ##inputs
                             LInputs=LInputSeries,                                                         ### length of input and output series
                             InputsPrecip=InputsModel$LayerPrecip[[iLayer]][IndPeriod1],                   ### input series of total precipitation [mm/d]
                             InputsFracSolidPrecip=InputsModel$LayerFracSolidPrecip[[iLayer]][IndPeriod1], ### input series of fraction of solid precipitation [0-1]
                             InputsTemp=InputsModel$LayerTemp[[iLayer]][IndPeriod1],                       ### input series of air mean temperature [degC]
                             MeanAnSolidPrecip=RunOptions$MeanAnSolidPrecip[iLayer],                       ### value of annual mean solid precip [mm/y]
-                            NParam=as.integer(NParam),                                                    ### number of model parameter = 2
+                            NParam=as.integer(NParamCN),                                                  ### number of model parameters = 2 or 4
                             Param=as.double(ParamCemaNeige),                                              ### parameter set
-                            NStates=as.integer(NStates),                                                  ### number of state variables used for model initialising = 2
+                            NStates=as.integer(NStates),                                                  ### number of state variables used for model initialising = 4
                             StateStart=StateStartCemaNeige,                                               ### state variables used when the model run starts
                             IsHyst = as.integer(IsHyst),                                                  ### use of hysteresis
                             NOutputs=as.integer(length(IndOutputsCemaNeige)),                             ### number of output series
                             IndOutputs=IndOutputsCemaNeige,                                               ### indices of output series
                         ##outputs                                                               
                             Outputs=matrix(as.double(-999.999),nrow=LInputSeries,ncol=length(IndOutputsCemaNeige)), ### output series [mm]
-                            StateEnd=rep(as.double(-999.999),as.integer(NStates))                                   ### state variables at the end of the model run (reservoir levels [mm] and HU)
+                            StateEnd=rep(as.double(-999.999),as.integer(NStates))                                   ### state variables at the end of the model run
                          )
         RESULTS$Outputs[ round(RESULTS$Outputs ,3)==(-999.999)] <- NA;
         RESULTS$StateEnd[round(RESULTS$StateEnd,3)==(-999.999)] <- NA;
@@ -110,7 +111,7 @@ RunModel_CemaNeigeGR5J <- function(InputsModel,RunOptions,Param){
       }
 
     ##Call_fortan
-      RESULTS <- .Fortran("frun_GR5J",PACKAGE="airGR",
+      RESULTS <- .Fortran("frun_gr5j",PACKAGE="airGR",
                  ##inputs
                      LInputs=LInputSeries,                          ### length of input and output series
                      InputsPrecip=CatchMeltAndPliq,                 ### input series of total precipitation [mm/d]
